# ADR-{{ACID}}: {{TITLE}}

**Applies to:** {{PREFIX}} project
**Last updated:** {{DATE}}
**Last reviewed:** {{DATE}}
**Status:** Proposed

---

## What Is It?

<description>

---

## Context

<context and background>

## Decision

<what was decided>

## Consequences

<positive and negative consequences>

---

## Change History

| Date | Change | By |
|------|--------|----|
| {{DATE}} | Initial version | — |
